@@ -73,17 +73,5 @@ withOptions <- function(expr, ..., args=list(), substitute=TRUE, envir=parent.fr
   })
   if (length(new) > 0L) options(new)
 
-  eval(expr, envir=envir)
+  eval(expr, envir = envir, enclos = baseenv())
 } # withOptions()
-
-
-############################################################################
-# HISTORY:
-# 2014-09-15
-# o ROBUSTNESS: Now withOptions() also resets the the options at entry
-#   even if no explicit options were specified.  This covers the case
-#   when the 'expr' changes the options, e.g.
-#   withOptions({ options(width=10); str(letter) }).
-# 2014-05-01
-# o Created.
-############################################################################
